# PewDiePy

This project has no utility yet. It exists only to claim the package name `pewdiepy` on `pypa` which is a play on the name of the youtuber PewDiePie. I'll think of some utility related to PewDiePie and publish a newer version of package.

If any lost soul makes their way to this repository, please open an issue and give me some ideas.